@@ -1,4 +1,4 @@
-# $Id: HTTPS.pm,v 1.3 2007/12/13 23:00:08 dk Exp $
+# $Id: HTTPS.pm,v 1.4 2007/12/16 20:20:16 dk Exp $
 package IO::Lambda::HTTPS;
 
 use vars qw(@ISA @EXPORT_OK);
@@ -70,3 +70,49 @@ sub single_request
 }
 
 1;
+
+__DATA__
+
+=pod
+
+=head1 NAME
+
+IO::Lambda::HTTPS - https requests lambda style
+
+=head1 DESCRIPTION
+
+The module exports a single lambda C<https_request> that behaves exactly
+as C<IO::Lambda::HTTP::http_request>. See L<IO::Lambda::HTTP> for detailed
+explanation of the behavior.
+
+=head1 SYNOPSIS
+
+   use HTTP::Request;
+   use IO::Lambda qw(:all);
+   use IO::Lambda::HTTP qw(https_request);
+   
+   my $r = HTTP::Request-> new( GET => "https://addons.mozilla.org/en-US/firefox");
+   $req-> protocol('HTTP/1.1');
+   $req-> headers-> header( Host => $a-> uri-> host);
+   $req-> headers-> header( Connection => 'close');
+   
+   this http_request {
+      my $res = shift;
+      if ( ref($result)) {
+         print "good:", length($result-> content), "\n";
+      } else {
+         print "bad:$result\n";
+      }
+   };
+
+   this-> wait;
+
+=head1 SEE ALSO
+
+L<IO::Lambda::HTTP>
+
+=head1 AUTHOR
+
+Dmitry Karasik, E<lt>dmitry@karasik.eu.orgE<gt>.
+
+=cut
